<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="75"/>
        <location filename="../mainwindow.cpp" line="396"/>
        <location filename="../mainwindow.cpp" line="446"/>
        <source>MX Cleanup</source>
        <translation>MX Nettoyage</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <source>Clean Folders</source>
        <translation>Dossiers à nettoyer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="119"/>
        <source>Display help </source>
        <translation>Afficher l&apos;aide</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="122"/>
        <source>Help</source>
        <translation>Aide</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="129"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="158"/>
        <source>About this application</source>
        <translation>À propos de cette application</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="161"/>
        <source>About...</source>
        <translation>À propos...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="200"/>
        <source>Quit application</source>
        <translation>Quitter l&apos;application</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="203"/>
        <location filename="../mainwindow.cpp" line="513"/>
        <source>Close</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="210"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="248"/>
        <source>Apply</source>
        <translation>Appliquer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="276"/>
        <source>Empty Trash</source>
        <translation>Vider la corbeille</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="282"/>
        <source>Trash older than:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="289"/>
        <location filename="../mainwindow.ui" line="426"/>
        <location filename="../mainwindow.ui" line="625"/>
        <source>Don&apos;t empty</source>
        <translation>Ne pas vider</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="299"/>
        <location filename="../mainwindow.ui" line="657"/>
        <source> days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="318"/>
        <source>All users</source>
        <translation>Tous les utilisateurs</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="337"/>
        <source>Selected user</source>
        <translation>Utilisateur sélectionné</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="385"/>
        <source>Clear APT Cache</source>
        <translation>Vider le cache APT</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="397"/>
        <source>Old files</source>
        <translation>Anciens fichiers</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="416"/>
        <source>All files</source>
        <translation>Tous les fichiers</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="540"/>
        <source>Free Disk Space for User</source>
        <translation>Espace disque libre de l&apos;utilisateur</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="552"/>
        <location filename="../mainwindow.ui" line="565"/>
        <source>Select user to repair</source>
        <translation>Sélectionner l&apos;utilisateur devant être modifié</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="568"/>
        <source>Select user:</source>
        <translation>Choix de l&apos;utilisateur:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="699"/>
        <source>Kernel removal tool</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="705"/>
        <source>List and select kernels to remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="458"/>
        <source>Graphical Tool for Analyzing Disk Usage</source>
        <translation>Outil graphique d&apos;analyse de l&apos;usage du disque</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="464"/>
        <source>Run Disk Usage Analyzer</source>
        <translation>Lancer l&apos;analyse de l&apos;usage du disque</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="478"/>
        <source>Schedule</source>
        <translation>Programme</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="490"/>
        <source>No automatic clean</source>
        <translation>Pas de nettoyage automatique</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="497"/>
        <source>Daily</source>
        <translation>Quotidien</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="504"/>
        <source>Weekly</source>
        <translation>Hebdomadaire</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="511"/>
        <source>Monthly</source>
        <translation>Mensuel</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="584"/>
        <source>Delete Logs</source>
        <translation>Supprimer les fichiers journaux</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="609"/>
        <source>All logs</source>
        <translation>Tous les journaux</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="641"/>
        <source>Old logs</source>
        <translation>Anciens journaux</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="676"/>
        <source>Logs older than:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="388"/>
        <source>Done</source>
        <translation>Terminé</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="388"/>
        <source>Cleanup command done</source>
        <translation>Commande de nettoyage executée</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="389"/>
        <source>%1 MiB were freed</source>
        <translation>%1 Mio sont de nouveau disponibles</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="396"/>
        <source>About</source>
        <translation>À propos</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="398"/>
        <source>Version: </source>
        <translation>Version: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="399"/>
        <source>Quick and safe removal of old files</source>
        <translation>Suppression des fichiers anciens sûre et rapide</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="401"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="402"/>
        <location filename="../mainwindow.cpp" line="413"/>
        <source>License</source>
        <translation>Licence</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="403"/>
        <location filename="../mainwindow.cpp" line="421"/>
        <source>Changelog</source>
        <translation>Journal des modifications</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="404"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="428"/>
        <source>&amp;Close</source>
        <translation>&amp;Fermer</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="508"/>
        <source>Kernel currently in use: &lt;b&gt;%1&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="511"/>
        <source>Remove selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="516"/>
        <source>Similar kernels that can be removed:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="517"/>
        <source>Other kernels that can be removed:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="519"/>
        <source>&lt;b&gt;Nothing to remove.&lt;/b&gt; Cannot remove kernel in use.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>You must run this program as root.</source>
        <translation type="vanished">Vous devez lancer cette application avec les droits administrateur.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="45"/>
        <source>Quick safe removal of old files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="67"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
